# Volumes Directory

This directory can hold a number of sub-directories used for extra testing.
The files expected there are copyrighted and thus are not checked in.
If you want to run the extra test place the following directories there:

  - *sc* Installation Directory of SAS/C 6.58 for Amiga
  - *wb* Workbench 3.1.4 and Module 3.1.4 disk contents. Use `build_wb.sh`
    script to fill directory from original ADF disk images.
